@@ -359,6 +359,8 @@ _OptionalChannelMessageCallbackTypeDef = TypedDict(
     {
         "Content": str,
         "Metadata": str,
+        "PushNotification": "PushNotificationConfigurationTypeDef",
+        "MessageAttributes": Mapping[str, "MessageAttributeValueTypeDef"],
     },
     total=False,
 )
@@ -1169,7 +1171,7 @@ ListTagsForResourceResponseTypeDef = TypedDict(
 MessageAttributeValueTypeDef = TypedDict(
     "MessageAttributeValueTypeDef",
     {
-        "StringValues": List[str],
+        "StringValues": Sequence[str],
     },
     total=False,
 )
@@ -1206,6 +1208,7 @@ PushNotificationConfigurationTypeDef = TypedDict(
         "Body": str,
         "Type": PushNotificationTypeType,
     },
+    total=False,
 )
 
 _RequiredPushNotificationPreferencesTypeDef = TypedDict(
